@@ -5,12 +5,12 @@ import json
 import os
 
 from marshmallow.exceptions import ValidationError
-from rich.prompt import Confirm
+from rich.prompt import Confirm, Prompt
 
 from .base import Lister, ShowOne, Command
 from ..error_handlers import CLIError
 from .. import schemas
-from ..utils import is_tty
+from ..utils import is_tty, t_or_f_or_n
 
 
 class ListDomain(Lister):
@@ -31,7 +31,7 @@ class CreateDomain(ShowOne):
         parser.add_argument(
             'name',
             metavar='<name>',
-            help='Domain name'
+            help='Domain name',
         )
         return parser
 
@@ -40,28 +40,154 @@ class CreateDomain(ShowOne):
             'name': parsed_args.name,
         }
         domain = self.app.session.post('/edge/domains', payload)
-        nslookup_urls = (
-            "ns1.digikalacloud.com",
-            "ns2.digikalacloud.com",
+        result = self.app.session.get(
+            '/edge/domains/{}/ns-records'.format(domain["id"])
         )
         self.app.console.print(
-            "[green bold] Attention: \n Please change your domain NS records to"
-            " {} .[green bold]".format(" and ".join(nslookup_urls))
+            "[bold yellow]{}[/bold yellow]".format(
+                "Make sure to set DigiCloud NS records: \n\t [bold blue]{}[/bold blue]".format(
+                    "\n\t ".join(result["digicloud_ns_records"])
+                )
+            )
         )
         return domain
 
 
+class GetDomainDNSSEC(ShowOne):
+    """Get Domain DNSSEC"""
+    schema = schemas.DomainDNSSECDetails()
+
+    def get_parser(self, prog_name):
+        parser = super().get_parser(prog_name)
+        parser.add_argument(
+            'domain',
+            metavar='<domain>',
+            help='Domain name or id',
+        )
+        return parser
+
+    def get_data(self, parsed_args):
+        dnssec = self.app.session.get(
+            '/edge/domains/{}/dnssec'.format(parsed_args.domain)
+        )
+        return dnssec
+
+
+class EnableDomainDNSSEC(ShowOne):
+    """Enable domain dnssec."""
+    schema = schemas.DomainDNSSECDetails()
+
+    def get_parser(self, prog_name):
+        parser = super().get_parser(prog_name)
+        parser.add_argument(
+            'domain',
+            metavar='<domain>',
+            help='Domain name or id',
+        )
+        return parser
+
+    def get_data(self, parsed_args):
+        uri = '/edge/domains/{}/dnssec'.format(parsed_args.domain)
+        payload = {
+            "dnssec": True,
+        }
+        dnssec = self.app.session.patch(uri, payload)
+        return dnssec
+
+
+class DisableDomainDNSSEC(ShowOne):
+    """Disable domain dnssec."""
+    schema = schemas.DomainDNSSECDetails()
+
+    def get_parser(self, prog_name):
+        parser = super().get_parser(prog_name)
+        parser.add_argument(
+            'domain',
+            metavar='<domain>',
+            help='Domain name or id',
+        )
+        return parser
+
+    def get_data(self, parsed_args):
+        uri = '/edge/domains/{}/dnssec'.format(parsed_args.domain)
+        payload = {
+            "dnssec": False,
+        }
+        dnssec = self.app.session.patch(uri, payload)
+        return dnssec
+
+
+class GetDomainNSRecordSetting(ShowOne):
+    """Get Domain NS record setting"""
+    schema = schemas.DomainNSRecordsDetails()
+
+    def get_parser(self, prog_name):
+        parser = super().get_parser(prog_name)
+        parser.add_argument(
+            'domain',
+            metavar='<domain>',
+            help='Domain name or id',
+        )
+        return parser
+
+    def get_data(self, parsed_args):
+        result = self.app.session.get(
+            '/edge/domains/{}/ns-records'.format(parsed_args.domain)
+        )
+        return result
+
+
+class VerifyNSRecord(Command):
+    """Verify ns record"""
+
+    def get_parser(self, prog_name):
+        parser = super().get_parser(prog_name)
+        parser.add_argument(
+            'domain',
+            metavar='<domain>',
+            help='Domain name or id',
+        )
+        return parser
+
+    def take_action(self, parsed_args):
+        result = self.app.session.get(
+            '/edge/domains/{}/verify-ns-records'.format(parsed_args.domain)
+        )
+        if result["result"]:
+            self.app.console.print(
+                "[bold green]{}[/bold green]".format(
+                    "DigiCloud NS records fully activated."
+                )
+            )
+        else:
+            result = self.app.session.get(
+                '/edge/domains/{}/ns-records'.format(parsed_args.domain)
+            )
+            self.app.console.print(
+                "[bold red]{}[/bold red]".format(
+                    "DigiCloud was not able to verify your NS records."
+                )
+            )
+            self.app.console.print(
+                "[bold yellow]{}[/bold yellow]".format(
+                    "Make sure to set DigiCloud NS records: \n\t [bold blue]{}[/bold blue]".format(
+                        "\n\t ".join(result["digicloud_ns_records"])
+                    )
+                )
+            )
+
+
 class DeleteDomain(Command):
     def get_parser(self, prog_name):
         parser = super().get_parser(prog_name)
         parser.add_argument(
             'domain',
             metavar='<domain>',
-            help='Domain name or id'
+            help='Domain name or id',
         )
 
         parser.add_argument(
-            '--i-am-sure',
+            '--yes-i-really-mean-it',
             help='Use this switch to bypass confirmation',
             default=None,
             action='store_true'
@@ -69,15 +195,17 @@ class DeleteDomain(Command):
         return parser
 
     def take_action(self, parsed_args):
-        if not self.confirm_domain_deletion(parsed_args):
+        domain = self.app.session.get('/edge/domains/%s' % parsed_args.domain)
+        if not self.delete_domain_2_step(domain):
+            return
+        if not self.confirm_domain_deletion(parsed_args, domain):
             return
         self.app.session.delete('/edge/domains/%s' % parsed_args.domain)
 
-    def confirm_domain_deletion(self, parsed_args):
-        if parsed_args.i_am_sure:
+    def confirm_domain_deletion(self, parsed_args, domain):
+        if parsed_args.yes_i_really_mean_it:
             return True
         if is_tty():
-            domain = self.app.session.get('/edge/domains/%s' % parsed_args.domain)
             user_response = Confirm.ask(
                 "You're about to delete domain named [red bold]{}[/red bold]. "
                 "Are you sure?".format(
@@ -90,9 +218,25 @@ class DeleteDomain(Command):
         else:
             self.app.stderr.write(
                 "Unable to perform 'domain delete' operation in non-interactive mode,"
-                " without '--i-am-sure' switch\n")
+                " without '--yes-i-really-mean-it' switch\n")
             return False
 
+    def delete_domain_2_step(self, domain):
+        if is_tty():
+            domain_name = Prompt.ask(
+                "[red bold]Attention:[/red bold] "
+                "You're about to delete domain named [red bold]{}[/red bold]. "
+                "Are you sure? Please write the domain name".format(
+                    domain['name'],
+                )
+            )
+            if domain_name == domain["name"]:
+                return True
+            self.app.stdout.write("Wrong domain name!\n")
+            return False
+        else:
+            return True
+
 
 class ShowDomain(ShowOne):
     schema = schemas.EdgeDomainDetails()
@@ -102,7 +246,7 @@ class ShowDomain(ShowOne):
         parser.add_argument(
             'domain',
             metavar='<domain>',
-            help='Domain name or id'
+            help='Domain name or id',
         )
         return parser
 
@@ -111,16 +255,6 @@ class ShowDomain(ShowOne):
         return domain
 
 
-def t_or_f_or_n(arg):
-    upper_arg = str(arg).upper()
-    if 'TRUE'.startswith(upper_arg):
-        return True
-    elif 'FALSE'.startswith(upper_arg):
-        return False
-    else:
-        return None
-
-
 def get_record_schema(data):
     schema_map = {
         "A": schemas.ARecordDetailsSchema(),
@@ -142,6 +276,7 @@ class ListRecord(Lister):
             '--domain',
             metavar='<domain>',
             help='edge domain Name or ID',
+            required=True,
         )
         return parser
 
@@ -164,6 +299,7 @@ class ShowRecord(ShowOne):
             '--domain',
             metavar='<domain>',
             help='edge domain ID',
+            required=True,
         )
         return parser
 
@@ -188,6 +324,7 @@ class DeleteRecord(Command):
             '--domain',
             metavar='<domain>',
             help='edge domain Name or ID',
+            required=True,
         )
         return parser
 
@@ -210,6 +347,7 @@ class UpdateRecord(ShowOne):
             '--domain',
             metavar='<domain>',
             help='edge domain Name or ID.',
+            required=True,
         )
         parser.add_argument(
             '--name',
@@ -224,6 +362,12 @@ class UpdateRecord(ShowOne):
             choices=("2m", "10m", "30m", "1h", "3h", "10h",),
             required=False,
         )
+        parser.add_argument(
+            '--note',
+            metavar='<note>',
+            help='Note',
+            required=False,
+        )
         parser.add_argument(
             '--ip-address',
             metavar='<ip-address>',
@@ -283,6 +427,13 @@ class UpdateRecord(ShowOne):
             required=False,
             type=int,
         )
+        parser.add_argument(
+            '--proxy',
+            metavar='<proxy>',
+            help='proxy.',
+            required=False,
+            type=t_or_f_or_n,
+        )
         return parser
 
     def get_data(self, parsed_args):
@@ -311,7 +462,7 @@ class CreateRecord(ShowOne):
             '--name',
             metavar='<name>',
             help='Record name.',
-            required = True,
+            required=True,
         )
         parser.add_argument(
             '--type',
@@ -328,6 +479,12 @@ class CreateRecord(ShowOne):
             choices=("2m", "10m", "30m", "1h", "3h", "10h",),
             required=True,
         )
+        parser.add_argument(
+            '--note',
+            metavar='<note>',
+            help='Note',
+            required=False,
+        )
         parser.add_argument(
             '--ip-address',
             metavar='<ip-address>',
@@ -387,6 +544,13 @@ class CreateRecord(ShowOne):
             required=False,
             type=int,
         )
+        parser.add_argument(
+            '--proxy',
+            metavar='<proxy>',
+            help='proxy.',
+            required=False,
+            type=t_or_f_or_n,
+        )
         return parser
 
     def get_data(self, parsed_args):
@@ -867,7 +1031,7 @@ class UpdateSSL(ShowOne):
             '--type',
             metavar='<type>',
             help='SSL type.',
-            choices=("custom",),
+            choices=("custom", "auto", ),
         )
         parser.add_argument(
             '--policy',
@@ -893,6 +1057,23 @@ class UpdateSSL(ShowOne):
             help='SSL https redirect.',
             type=t_or_f_or_n,
         )
+        parser.add_argument(
+            '--ocsp-check',
+            metavar='<ocsp-check>',
+            help='SSL Ocsp',
+            type=t_or_f_or_n,
+        )
+        parser.add_argument(
+            '--min-tls-versions',
+            metavar='<min-tls-versions>',
+            help='SSL Min TLS Versions.',
+            choices=(
+                'TLS_1_0',
+                'TLS_1_1',
+                'TLS_1_2',
+                'TLS_1_3',
+            ),
+        )
         parser.add_argument(
             '--private-key',
             metavar='<private-key>',
@@ -920,26 +1101,21 @@ class UpdateSSL(ShowOne):
             payload["hsts"] = parsed_args.hsts
         if parsed_args.https_redirect is not None:
             payload["https_redirect"] = parsed_args.https_redirect
+        if parsed_args.ocsp_check is not None:
+            payload["ocsp_check"] = parsed_args.ocsp_check
+        if parsed_args.min_tls_versions is not None:
+            payload["min_tls_versions"] = parsed_args.min_tls_versions
         if parsed_args.public_key:
             with open(os.path.expanduser(parsed_args.public_key)) as file_:
                 payload["public_key"] = file_.read()
         if parsed_args.private_key:
             with open(os.path.expanduser(parsed_args.private_key)) as file_:
                 payload["private_key"] = file_.read()
+
         server = self.app.session.patch(uri, payload)
         return server
 
 
-def t_or_f_or_n(arg):
-    upper_arg = str(arg).upper()
-    if 'TRUE'.startswith(upper_arg):
-        return True
-    elif 'FALSE'.startswith(upper_arg):
-        return False
-    else:
-        return None
-
-
 class ListLocation(Lister):
     """List edge locations"""
     schema = schemas.LocationDetails(many=True)
@@ -1091,6 +1267,11 @@ class UpdateLocation(ShowOne):
             metavar='<cache-zone>',
             help='location cache zone id.',
         )
+        parser.add_argument(
+            '--rate-limit',
+            metavar='<rate-limit>',
+            help='location rate limit id.',
+        )
         return parser
 
     def get_data(self, parsed_args):
@@ -1132,6 +1313,8 @@ class UpdateLocation(ShowOne):
             payload["cache_cookie_name"] = parsed_args.cache_cookie_name
         if parsed_args.cache_zone:
             payload["cache_zone"] = parsed_args.cache_zone
+        if parsed_args.rate_limit:
+            payload["rate_limit_id"] = parsed_args.rate_limit
         location = self.app.session.patch(uri, payload)
         return location
 
@@ -1220,6 +1403,11 @@ class CreateLocation(ShowOne):
             metavar='<cache-zone>',
             help='location cache zone id.',
         )
+        parser.add_argument(
+            '--rate-limit',
+            metavar='<rate-limit>',
+            help='location rate limit id.',
+        )
         return parser
 
     def get_data(self, parsed_args):
@@ -1258,6 +1446,8 @@ class CreateLocation(ShowOne):
             payload["cache_cookie_name"] = parsed_args.cache_cookie_name
         if parsed_args.cache_zone:
             payload["cache_zone"] = parsed_args.cache_zone
+        if parsed_args.rate_limit:
+            payload["rate_limit_id"] = parsed_args.rate_limit
         location = self.app.session.post(url, payload)
         return location
 
@@ -1482,3 +1672,381 @@ class ListCacheZone(Lister):
     def get_data(self, parsed_args):
         domains = self.app.session.get('/edge/cache-zones')
         return domains
+
+
+class ShowGeneralSetting(ShowOne):
+    """Show general setting details."""
+    schema = schemas.GeneralSettingSchema()
+
+    def get_parser(self, prog_name):
+        parser = super().get_parser(prog_name)
+        parser.add_argument(
+            'domain',
+            metavar='<domain>',
+            help='edge domain name ID',
+        )
+        return parser
+
+    def get_data(self, parsed_args):
+        uri = '/edge/domains/{}/general-setting'.format(parsed_args.domain)
+        general_setting = self.app.session.get(uri)
+        return general_setting
+
+
+class UpdateGeneralSetting(ShowOne):
+    """Update general setting."""
+    schema = schemas.GeneralSettingSchema()
+
+    def get_parser(self, prog_name):
+        parser = super().get_parser(prog_name)
+        parser.add_argument(
+            'domain',
+            metavar='<domain>',
+            help='edge domain ID or name',
+        )
+        parser.add_argument(
+            '--developer-mode',
+            metavar='<developer-mode>',
+            help='General setting developer mode.',
+            type=t_or_f_or_n,
+            required=False,
+        )
+        parser.add_argument(
+            '--maintenance-mode',
+            metavar='<maintenance-mode>',
+            help='General setting maintenance mode.',
+            type=t_or_f_or_n,
+            required=False,
+        )
+        parser.add_argument(
+            '--redirect-to-www',
+            metavar='<redirect-to-www>',
+            help='General setting redirect to www.',
+            type=t_or_f_or_n,
+            required=False,
+        )
+        parser.add_argument(
+            '--ip-geolocation',
+            metavar='<ip-geolocation>',
+            help='General setting ip geo location.',
+            type=t_or_f_or_n,
+            required=False,
+        )
+        parser.add_argument(
+            '--intercept-errors',
+            metavar='<intercept_errors>',
+            help='General setting intercepts errors.',
+            type=t_or_f_or_n,
+            required=False,
+        )
+        parser.add_argument(
+            '--max-upload-size',
+            metavar='<max-upload-size>',
+            help='General setting max upload size.',
+            type=int,
+            required=False,
+        )
+        parser.add_argument(
+            '--custom-host-header',
+            metavar='<custom-host-header>',
+            help='General setting custom host header.',
+            type=str,
+            required=False,
+        )
+        parser.add_argument(
+            '--origin-headers',
+            metavar='<origin-headers>',
+            help='location origin headers.',
+            required=False,
+        )
+        parser.add_argument(
+            '--response-headers',
+            metavar='<response-headers>',
+            help='location response headers.',
+            required=False,
+        )
+        return parser
+
+    def get_data(self, parsed_args):
+        uri = '/edge/domains/{}/general-setting'.format(
+            parsed_args.domain,
+        )
+        payload = {}
+        if parsed_args.developer_mode is not None:
+            payload["developer_mode"] = parsed_args.developer_mode
+        if parsed_args.maintenance_mode is not None:
+            payload["maintenance_mode"] = parsed_args.maintenance_mode
+        if parsed_args.redirect_to_www is not None:
+            payload["redirect_to_www"] = parsed_args.redirect_to_www
+        if parsed_args.ip_geolocation is not None:
+            payload["ip_geolocation"] = parsed_args.ip_geolocation
+        if parsed_args.intercept_errors is not None:
+            payload["intercept_errors"] = parsed_args.intercept_errors
+        if parsed_args.max_upload_size is not None:
+            payload["max_upload_size"] = parsed_args.max_upload_size
+        if parsed_args.custom_host_header:
+            payload["custom_host_header"] = parsed_args.custom_host_header
+        if parsed_args.origin_headers:
+            with open(os.path.expanduser(parsed_args.origin_headers)) as file_:
+                origin_headers_content = file_.read()
+                try:
+                    payload["origin_headers"] = json.loads(origin_headers_content)
+                except json.decoder.JSONDecodeError as e:
+                    raise CLIError(
+                        [dict(msg="origin-headers is not a valid json")])
+        if parsed_args.response_headers:
+            with open(os.path.expanduser(parsed_args.response_headers)) as file_:
+                response_headers_content = file_.read()
+                try:
+                    payload["response_headers"] = json.loads(response_headers_content)
+                except json.decoder.JSONDecodeError as e:
+                    raise CLIError(
+                        [dict(msg="response-headers is not a valid json")])
+        server = self.app.session.patch(uri, payload)
+        return server
+
+
+class PurgeCache(Command):
+    """purge cache"""
+    def get_parser(self, prog_name):
+        parser = super().get_parser(prog_name)
+        parser.add_argument(
+            'domain',
+            metavar='<domain>',
+            help='edge domain ID or name',
+        )
+        parser.add_argument(
+            '--url',
+            metavar='<url>',
+            help='url to purge cache',
+            required=True,
+        )
+        parser.add_argument(
+            '--method',
+            metavar='<method>',
+            help='Url method purge cache.',
+            choices=("GET", "HEAD", "OPTIONAL",),
+            type=str.upper,
+            required=False,
+        )
+        parser.add_argument(
+            '--cookies',
+            metavar='<cookies>',
+            help='purge cache url cookies path.',
+            required=False,
+        )
+
+        return parser
+
+    def take_action(self, parsed_args):
+        uri = '/edge/domains/{}/purge-cache'.format(
+            parsed_args.domain,
+        )
+        payload = {}
+        if parsed_args.url:
+            payload["url"] = parsed_args.url
+        if parsed_args.method:
+            payload["method"] = parsed_args.method
+        if parsed_args.cookies:
+            with open(os.path.expanduser(parsed_args.cookies)) as file_:
+                cookie_content = file_.read()
+                try:
+                    payload["cookies"] = json.loads(cookie_content)
+                except json.decoder.JSONDecodeError as e:
+                    raise CLIError(
+                        [dict(msg="cookies is not a valid json")])
+        server = self.app.session.post(uri, payload)
+        return server
+
+
+class ListRateLimit(Lister):
+    """List edge rate limits"""
+    schema = schemas.RateLimitDetails(many=True)
+
+    def get_parser(self, prog_name):
+        parser = super().get_parser(prog_name)
+        parser.add_argument(
+            '--domain',
+            metavar='<domain>',
+            help='edge domain Name or ID',
+            required=True,
+        )
+        return parser
+
+    def get_data(self, parsed_args):
+        rate_limits = self.app.session.get('/edge/domains/{}/rate-limits'.format(parsed_args.domain))
+        return rate_limits
+
+
+class ShowRateLimit(ShowOne):
+    """Show rate limit details."""
+    schema = schemas.RateLimitDetails()
+
+    def get_parser(self, prog_name):
+        parser = super().get_parser(prog_name)
+        parser.add_argument(
+            'rate_limit',
+            metavar='<rate-limit>',
+            help='edge rate limit name or ID',
+        )
+        parser.add_argument(
+            '--domain',
+            metavar='<domain>',
+            help='edge domain ID',
+            required=True,
+        )
+        return parser
+
+    def get_data(self, parsed_args):
+        uri = '/edge/domains/{}/rate-limits/{}'.format(parsed_args.domain, parsed_args.rate_limit)
+        rate_limit = self.app.session.get(uri)
+        return rate_limit
+
+
+class DeleteRateLimit(Command):
+    """Delete rate limit."""
+
+    def get_parser(self, prog_name):
+        parser = super().get_parser(prog_name)
+        parser.add_argument(
+            'rate_limit',
+            metavar='<rate-limit>',
+            help='edge rate limit name or ID',
+        )
+        parser.add_argument(
+            '--domain',
+            metavar='<domain>',
+            help='edge domain Name or ID',
+            required=True,
+        )
+        return parser
+
+    def take_action(self, parsed_args):
+        uri = '/edge/domains/{}/rate-limits/{}'.format(parsed_args.domain, parsed_args.rate_limit)
+        self.app.session.delete(uri)
+
+
+class UpdateRateLimit(ShowOne):
+    """Update rate limit."""
+    schema = schemas.RateLimitDetails()
+
+    def get_parser(self, prog_name):
+        parser = super().get_parser(prog_name)
+        parser.add_argument(
+            'rate_limit',
+            metavar='<rate-limit>',
+            help='edge rate limit name or ID',
+        )
+        parser.add_argument(
+            '--domain',
+            metavar='<domain>',
+            help='edge domain Name or ID.',
+            required=True,
+        )
+        parser.add_argument(
+            '--name',
+            metavar='<name>',
+            help='rate limit name.',
+        )
+        parser.add_argument(
+            '--requests',
+            metavar='<requests>',
+            help='edge rate limit requests.',
+            type=int,
+        )
+        parser.add_argument(
+            '--burst',
+            metavar='<burst>',
+            help='rate limit burst type.',
+            type=int,
+        )
+        parser.add_argument(
+            '--exclusions',
+            metavar='<exclusions>',
+            help='List rate limit exclusions.',
+            nargs='+',
+        )
+        parser.add_argument(
+            '--time',
+            metavar='<time>',
+            help='rate limit time.',
+            choices=("s", "m",),
+        )
+        return parser
+
+    def get_data(self, parsed_args):
+        uri = '/edge/domains/{}/rate-limits/{}'.format(parsed_args.domain, parsed_args.rate_limit)
+        payload = {}
+        if parsed_args.name:
+            payload["name"] = parsed_args.name
+        if parsed_args.requests:
+            payload["requests"] = parsed_args.requests
+        if parsed_args.burst:
+            payload["burst"] = parsed_args.burst
+        if parsed_args.time:
+            payload["time"] = parsed_args.time
+        if parsed_args.exclusions:
+            payload["exclusion_list"] = parsed_args.exclusions
+        rate_limit = self.app.session.patch(uri, payload)
+        return rate_limit
+
+
+class CreateRateLimit(ShowOne):
+    """Create rate limit"""
+    schema = schemas.RateLimitDetails()
+
+    def get_parser(self, prog_name):
+        parser = super().get_parser(prog_name)
+        parser.add_argument(
+            '--domain',
+            metavar='<domain>',
+            help='edge domain Name or ID.',
+            required=True,
+        )
+        parser.add_argument(
+            '--name',
+            metavar='<name>',
+            help='rate limit name.',
+            required=True,
+        )
+        parser.add_argument(
+            '--requests',
+            metavar='<requests>',
+            help='edge rate limit requests.',
+            type=int,
+            required=True,
+        )
+        parser.add_argument(
+            '--burst',
+            metavar='<burst>',
+            help='rate limit burst type.',
+            type=int,
+            required=True,
+        )
+        parser.add_argument(
+            '--exclusions',
+            metavar='<exclusions>',
+            help='List rate limit exclusions.',
+            nargs='+',
+        )
+        parser.add_argument(
+            '--time',
+            metavar='<time>',
+            help='rate limit time.',
+            choices=("s", "m",),
+            required=True,
+        )
+        return parser
+
+    def get_data(self, parsed_args):
+        url = '/edge/domains/{}/rate-limits'.format(parsed_args.domain)
+        payload = {
+            "name": parsed_args.name,
+            "requests": parsed_args.requests,
+            "burst": parsed_args.burst,
+            "time": parsed_args.time,
+        }
+        if parsed_args.exclusions:
+            payload["exclusion_list"] = parsed_args.exclusions
+        rate_limit = self.app.session.post(url, payload)
+        return rate_limit
