@@ -63,15 +63,28 @@ class ErrorHandler:
         )])
 
     def _on_quota_exceeded(self, error):
-        return CLIError([dict(
-            msg="{message} {description} is {quota} but you used {used}.".format(
-                message=error['message'],
-                description=rule['description'],
-                quota=rule['quota'],
-                used=rule['used'],
-            ),
-            hint="Request more quota.",
-        ) for rule in error["rules"]])
+        cli_errors = []
+        for rule in error["rules"]:
+            if rule["used"].lower() != "none":
+                message = "{message} {description} is {quota} but you used {used}.".format(
+                        message=error['message'],
+                        description=rule['description'],
+                        quota=rule['quota'],
+                        used=rule['used'],
+                    )
+            else:
+                message = "{message} {description} is {quota}.".format(
+                        message=error['message'],
+                        description=rule['description'],
+                        quota=rule['quota'],
+                    )
+            cli_errors.append(
+                dict(
+                    msg=message,
+                    hint="Request more quota.",
+                )
+            )
+        return CLIError(cli_errors)
 
     def _on_unauthorized(self, error):
         return CLIError([dict(
