@@ -93,6 +93,7 @@ class RouterList(Schema):
     name = fields.Str()
     description = fields.Str()
     has_gateway = fields.Str()
+    gateway_address = fields.Str()
     admin_state = fields.Str()
     status = fields.Str()
     updated_at = APIDatetime()
@@ -284,6 +285,31 @@ class InstanceInterface(Schema):
         ordered = True
 
 
+class ListInstanceInterface(Schema):
+    id = fields.Str()
+    network_id = fields.Str()
+    mac_address = fields.Str()
+    port_state = fields.Str()
+    public_ip = fields.Str()
+    port_security_enabled = fields.Boolean()
+    fixed_ips = fields.List(fields.Dict())
+
+    class Meta:
+        ordered = True
+
+
+class InstanceInterfaceDetail(Schema):
+    id = fields.Str()
+    admin_state = fields.Str()
+    mac_addr = fields.Str()
+    port_security_enabled = fields.Bool()
+    updated_at = APIDatetime(datetime_format="%Y-%m-%dT%H:%M:%SZ")
+    created_at = APIDatetime(datetime_format="%Y-%m-%dT%H:%M:%SZ")
+
+    class Meta:
+        ordered = True
+
+
 class SnapshotList(Schema):
     name = fields.Str()
     description = fields.Str()
@@ -546,13 +572,30 @@ class EdgeDomainDetails(Schema):
         ordered = True
 
 
+class DomainDNSSECDetails(Schema):
+    dnssec = fields.Boolean()
+    ds = fields.Str()
+
+    class Meta:
+        ordered = True
+
+
+class DomainNSRecordsDetails(Schema):
+    digicloud_ns_records = fields.List(fields.Str())
+
+    class Meta:
+        ordered = True
+
+
 class RecordListSchema(Schema):
-    available_keys = ("id", "name", "ttl", "type", "ip_address", "proxy", "content", "port", "weight", "proto",
+    available_keys = ("id", "name", "ttl", "note", "type", "ip_address", "proxy", "content", "port", "weight", "proto",
                       "service", "target", "priority", "mail_server",)
     id = fields.Str()
     name = fields.Str(required=True)
     type = fields.Str(required=True)
     ttl = fields.Str(required=True)
+    note = fields.Str(required=False)
+    proxy = fields.Boolean(required=False)
 
     class Meta:
         ordered = True
@@ -560,6 +603,7 @@ class RecordListSchema(Schema):
 
 class ARecordDetailsSchema(RecordListSchema):
     ip_address = fields.Str(required=True)
+    proxy = fields.Boolean(required=False, missing=False)
 
 
 class TXTRecordDetailsSchema(RecordListSchema):
@@ -568,6 +612,7 @@ class TXTRecordDetailsSchema(RecordListSchema):
 
 class CNAMERecordDetailsSchema(RecordListSchema):
     target = fields.Str(required=True)
+    proxy = fields.Boolean(required=False, missing=False)
 
 
 class MXRecordDetailsSchema(RecordListSchema):
@@ -669,6 +714,129 @@ class LoadBalancerDetail(Schema):
         ordered = True
 
 
+class AccessKeyDetails(Schema):
+    access_key = fields.Str()
+    secret_key = fields.Str()
+    is_active = fields.Boolean()
+
+    class Meta:
+        ordered = True
+
+
+class UpstreamDetails(Schema):
+    id = fields.Str()
+    name = fields.Str()
+    lb_method = fields.Str()
+    keep_alive = fields.Int()
+    ssl_policy = fields.Str()
+    servers_count = fields.Int()
+
+    class Meta:
+        ordered = True
+
+
+class UpstreamServerDetails(Schema):
+    id = fields.Str()
+    ip_domain = fields.Str()
+    port = fields.Int()
+    weight = fields.Int()
+    fail_timeout = fields.Int()
+
+    class Meta:
+        ordered = True
+
+
+class SSLDetails(Schema):
+    id = fields.Str()
+    type = fields.Str()
+    policy = fields.Str()
+    enable = fields.Boolean()
+    hsts = fields.Boolean()
+    https_redirect = fields.Boolean()
+    ocsp_check = fields.Boolean()
+    min_tls_versions = fields.Str()
+    expires_at = APIDatetime()
+    updated_at = APIDatetime()
+
+    class Meta:
+        ordered = True
+
+
+class LocationDetails(Schema):
+    id = fields.Str()
+    name = fields.Str()
+    path = fields.Str()
+    path_type = fields.Str()
+    path_extensions = fields.List(fields.Str())
+    upstream_id = fields.Str()
+    origin_headers = fields.List(fields.Dict())
+    response_headers = fields.List(fields.Dict())
+    updated_at = APIDatetime()
+    cache_enabled = fields.Bool()
+    cache_ttl = fields.Str()
+    cache_key = fields.Str()
+    cache_cookie_name = fields.Str()
+    cache_zone = fields.Str()
+    rate_limit_id = fields.Str()
+
+    class Meta:
+        ordered = True
+
+
+class EdgeFirewallDetails(Schema):
+    id = fields.Str()
+    location_id = fields.Str()
+    input = fields.Str()
+    value = fields.Str()
+    action = fields.Str()
+    operator = fields.Str()
+    priority = fields.Int()
+    updated_at = APIDatetime()
+
+    class Meta:
+        ordered = True
+
+
+class CacheZoneList(Schema):
+    id = fields.Str()
+    name = fields.Str()
+
+    class Meta:
+        ordered = True
+
+
+class GeneralSettingSchema(Schema):
+    id = fields.Str()
+    origin_headers = fields.List(fields.Dict())
+    response_headers = fields.List(fields.Dict())
+    developer_mode = fields.Boolean()
+    maintenance_mode = fields.Boolean()
+    redirect_to_www = fields.Boolean()
+    ip_geolocation = fields.Boolean()
+    intercept_errors = fields.Boolean()
+    max_upload_size = fields.Int()
+    custom_host_header = fields.Str()
+    created_at = fields.Str(dump_only=True)
+    updated_at = fields.Str(dump_only=True)
+
+    class Meta:
+        ordered = True
+
+
+class RateLimitDetails(Schema):
+    id = fields.Str()
+    name = fields.Str()
+    time = fields.Str()
+    requests = fields.Int()
+    burst = fields.Int()
+    exclusion_list = fields.List(fields.Str())
+    created_at = fields.Str()
+    updated_at = fields.Str()
+
+    class Meta:
+        ordered = True
+
+
 def handle_nested_data_keys(data, nested_data, nested_key):
     if isinstance(nested_data, dict):
         for key, value in nested_data.items():
@@ -677,5 +845,3 @@ def handle_nested_data_keys(data, nested_data, nested_key):
         for index, item in enumerate(nested_data):
             for key, value in item.items():
                 data["%s_%s_%s" % (nested_key, index, key)] = value
-
-
